@@ -21,11 +21,12 @@ name
 #path="C:/Program Files/Tinn-R/bin/Tinn-R.exe" # path to editor.
 )
 {
+warning("funTinn will be removed from berryFunctions in late 2017. I recommend to use funSource instead.")
 File <- paste0(tempdir(), "/", deparse(substitute(name)), ".r")
 sink(File)
 print(name)
 sink()
 #dummy <- edit(name, editor=path)
 # Open the file with the program associated with its file extension
-system2("open", File)
+openFile(File)
 }
