@@ -15,22 +15,28 @@
 #' @export
 #' @examples
 #' 
+#' \dontrun{ # excluded from CRAN checks, file opening not wanted
+#' pdfpng(   plot(rnorm(500), type="l")   , file="dummyplot", png=FALSE)
+#' }
+#' 
 #' pdfpng({par(bg=8, las=1); plot(cumsum(rnorm(500)), type="l")},
-#'        file="dummyplot", res=100)
+#'        file="dummyplot", res=100, open=FALSE)
 #' pdfpng({par(bg=8, las=1); plot(cumsum(rnorm(500)), type="l")},
-#'        file="dummyplot", overwrite=c(TRUE,FALSE))
+#'        file="dummyplot", overwrite=c(TRUE,FALSE), open=FALSE)
 #' 
 #' # Nesting of functions is possible:
 #' a <- list( cumsum(rnorm(2000)), cumsum(rnorm(20)) )
-#' pdfpng(plot(a[[1]]), file="dummyplot", overwrite=TRUE)
-#' bfun <- function(b) pdfpng(plot(b,type="l"), file="dummyplot", overwrite=TRUE)
+#' pdfpng(plot(a[[1]]), file="dummyplot", overwrite=TRUE, open=FALSE)
+#' bfun <- function(b) pdfpng(plot(b,type="l"), file="dummyplot", 
+#'                            overwrite=TRUE, open=FALSE)
 #' cfun <- function(c) bfun(c)
 #' bfun(a[[1]])
 #' sapply(a, function(d) cfun(d))
 #' 
 #' 
-#' pdfpng(plot(-10:100, log="y"), "dummyplot", overwrite=TRUE, png=FALSE)
-#' pdfpng({plot(1); plot(dummyobject)}, "dummyplot", overwrite=TRUE, png=FALSE)
+#' pdfpng(plot(-10:100, log="y"), "dummyplot",overwr=TRUE,png=FALSE, open=FALSE)
+#' pdfpng({plot(1); plot(dummyobject)}, "dummyplot", overwrite=TRUE, 
+#'        png=FALSE, open=FALSE)
 #' 
 #' 
 #' unlink("dummyplot.pdf") ; unlink("dummyplot.png") ; unlink("dummyplot_1.png")
@@ -48,6 +54,8 @@
 #' @param overwrite    Logical: Overwrite existing \code{file}? Can be a vector
 #'                     for pdf and png separately.
 #'                     DEFAULT: FALSE (_n appended in filename)
+#' @param open         Logical: open file(s) after creation using \code{\link{openFile}}? 
+#'                     DEFAULT: TRUE 
 #' @param quiet        Logical: suppress file creation messages and
 #'                     expr execution error tracing? DEFAULT: FALSE
 #' @param tracewarnmes Logical: trace warnings and messages in expr execution?
@@ -71,6 +79,7 @@ pdfpng <- function(
  pdf=TRUE,
  png=TRUE,
  overwrite=FALSE,
+ open=TRUE,
  quiet=FALSE,
  tracewarnmes=!quiet,
  filargs=NULL,
@@ -120,5 +129,6 @@ if(png)
                    "eval(expr, p)"))
   dev.off()
 }
+if(open) openFile(fig)
 return(invisible(NULL))
 }
